from setuptools import setup

setup(name='stat-distpy',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['stat-distpy'],
      author='Luiz Alberto',
      author_email='gomes.luiz@gmail.com',
      zip_safe=False)
